@@ -2,14 +2,23 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <syslog.h>
+#ifdef HAVE_SYSLOG_H
+#  include <syslog.h>
+#endif
 #include <signal.h>
-#include <popt.h>
+#include <glib/goption.h>
+#include <glib/gi18n.h>
 #include "CosNaming_impl.h"
 
+#ifndef GETTEXT_PACKAGE
+#define GETTEXT_PACKAGE NULL
+#endif
+
 static void
 signal_handler(int signo){
+#ifdef HAVE_SYSLOG
   syslog(LOG_ERR,"Receveived signal %d\nshutting down.", signo);
+#endif
   switch(signo) {
     case SIGSEGV:
 	abort();
@@ -20,13 +29,9 @@ signal_handler(int signo){
 
 static char *opt_corbaloc_key = NULL;
 
-static const struct poptOption TheOptions[] = {
-    { "key", 0, POPT_ARG_STRING, &opt_corbaloc_key, 0, 
-    	"Respond to corbaloc requests with this object key", "string" },
-#if 0
-    ORBIT_POPT_TABLE,
-#endif
-    POPT_AUTOHELP
+static const GOptionEntry goptions[] = {
+    { "key", 0, 0, G_OPTION_ARG_STRING, &opt_corbaloc_key,
+      N_("Respond to corbaloc requests with this object key"), N_("KEY") },
     { NULL }
 };
 
@@ -38,8 +43,12 @@ main (int argc, char *argv[])
   CosNaming_NamingContext context;
   const char*		progname = "orbit-name-server";
   
+#ifdef HAVE_SYSLOG
   openlog(progname, LOG_NDELAY | LOG_PID, LOG_DAEMON);
   syslog(LOG_INFO,"starting");
+#endif
+
+#ifdef HAVE_SIGACTION
   {
   	sigset_t empty_mask;
   	struct sigaction act;
@@ -56,27 +65,38 @@ main (int argc, char *argv[])
   	act.sa_handler = SIG_IGN;
   	sigaction(SIGPIPE, &act, NULL);
   }
+#else
+  signal(SIGINT, signal_handler);
+#ifdef SIGHUP
+  signal(SIGHUP, signal_handler);
+#endif
+  signal(SIGSEGV, signal_handler);
+  signal(SIGABRT, signal_handler);
+#ifdef SIGPIPE
+  signal(SIGPIPE, SIG_IGN);
+#endif
+#endif
 
   CORBA_exception_init (&ev);
   orb = CORBA_ORB_init (&argc, argv, "orbit-local-orb", &ev);
   
   {
-  	poptContext	pcxt;
-	int		rc;
-        pcxt = poptGetContext(progname, argc, (const char**)argv, 
-		TheOptions, 0);
-      	if ( (rc=poptGetNextOpt(pcxt)) < -1 ) {
-	    g_warning("%s: bad argument %s: %s\n",
-	    		progname, 
-			poptBadOption(pcxt, POPT_BADOPTION_NOALIAS), 
-			poptStrerror(rc));
+        GOptionContext *context;
+        GError *error = NULL;
+        gboolean result;
+
+        context = g_option_context_new("");
+        g_option_context_add_main_entries(context, goptions, GETTEXT_PACKAGE);
+
+        result = g_option_context_parse(context, &argc, &argv, &error);
+        g_option_context_free(context);
+
+        if (!result) {
+            g_warning("%s: bad arguments: %s\n",
+                      progname, error->message);
+            g_error_free(error);
 	    exit(1);
-      }
-      if ( poptGetArg(pcxt) != 0 ) {
-	    g_warning("%s: leftover arguments.\n", progname);
-	    exit(1);
-      }
-      poptFreeContext(pcxt);
+        }
   }
 
   {
@@ -111,6 +131,8 @@ main (int argc, char *argv[])
   /* Don't release until done (dont know why) */
   CORBA_Object_release (context, &ev);
 
+#ifdef HAVE_SYSLOG
   syslog(LOG_INFO, "exiting");
+#endif
   return 0;
 }
